@@ -8,7 +8,7 @@ from .serializers import UserSerializer, UserWithDetailSerializer, UserLoginSeri
 
 
 class UserViewSet(viewsets.ModelViewSet):
-    queryset = User.objects.prefetch_related('groups').all()
+    queryset = User.objects.select_related('extended_user').prefetch_related('groups').all()
     serializer_class = UserSerializer
 
     @action(detail=True, methods=['post'])
